Object (list) containing the interpolation (curve fitting) of some seasonal cycles (dt_cycles) extracted from the dataset ts_filled, created following the example provided in the fit_curve() documentation. It is used in the documentation of function extract_pheno().

data(cf)

Format

A named list of 2 elements (one per input ID) in the output format of function fit_curve().