Data frame with the cycles extracted from the dataset
ts_filled, created following the example provided in the
cut_cycles() documentation.
It is used in the documentation of function fit_curve().
data(dt_cycles)A data table with 3 records (identified cycles) and the following fields:
id: the time series ID;
year: the year assigned to each cycle;
cycle: the cycle ID (progressive integer within each year);
begin: the date of the begin of the cycle;
end: the date of the end of the cycle;
maxval: the date of the maximum value of the cycle;
weight: the value of the metric used for ranking seasons.
data(dt_cycles)
dt_cycles
#> id year cycle begin end maxval weight
#> 1: 1 2020 1 2020-04-27 2020-10-15 2020-07-13 88.71541
#> 2: 2 2020 1 2020-01-04 2020-07-16 2020-04-21 92.78070
#> 3: 2 2020 2 2020-07-16 2020-10-16 2020-08-08 13.91427