This function computes and returns the approximate pole of
inaccessibility (visual centre) for a polygon using the quadtree-based
algorithm implemented in polylabelr::poi(),
accepting an input in the same format of sf_centroid()
(sf, sfc or sfg)
and returning an output in the same format of x.
st_poi(x, ..., precision)object of class sfg, sfc or sf
Ignored
The precision to use when computing the centre
(passed to polylabelr::poi()), in the x unit.
If missing, by default it is used the 1/1000 of the mean square root of the
area of inputs.